<?php

/**
 * event
 */

class event{

	const _INSERT_ = 'INSERT INTO events (titre, description, dateEvent, heureDebut, heureFin, userId, emails)
	VALUES (?,?,?,?,?,?,?);';
	
	const _UPDATE_ = '
	UPDATE events SET
	titre = ?,
	description = ?,
	dateEvent = ?,
	heureDebut = ?,
	heureFin = ?,
	userId = ?,
	emails = ?
	WHERE id = ?
	';
	const _FINDBYID_ = 'SELECT * FROM events WHERE id = ?';
	const _FINDBYDATE_ = 'SELECT * FROM events WHERE dateEvent = ?';
	const _DELETE_ = 'DELETE FROM events WHERE id = ?';
	const _NEW_ = -1;
	
	private $dbh,
		$event = array('id'=>self::_NEW_, 'titre'=>'','description'=>'',
			'dateEvent'=>'','heureDebut'=>'','heureFin'=>'',
			'userId'=>'','emails'=>'');

	/**
	 * __construct
	 */
	public function __construct($dbh){
		$this->dbh = $dbh;
	}
	
	/**
	 * __set
	 */
	public function __set($var, $val){
		if(!@array_key_exists($var, $this->event))
			throw new exception('The variable '.$var.' doesn\'t exist');
		else
			$this->event[$var] = $val;
	}
	
	/**
	 * __get
	 */
	public function __get($var){
		if(@array_key_exists($var, $this->event))
			return $this->event[$var];
		throw new exception('The variable '.$var.' doesn\'t exist');
		return false;
	}
	
	/**
	 * loadEvent
	 */
	private function loadEvent($params = array()){
		$newEvent = new event($this->dbh, $this->event['userId']);
		foreach($params as $param => $value)
			$newEvent->$param = $value;
			
		return $newEvent;
	}
	
	/**
	 * insert
	 */
	private function insert(){
		$insert = $this->dbh->prepare(self::_INSERT_);
		$params = array(
				$this->event['titre'],
				$this->event['description'],
				$this->event['dateEvent'],
				$this->event['heureDebut'],
				$this->event['heureFin'],
				$this->event['userId'],
				$this->event['emails']
			   );
		return $insert->execute($params);
	}
	
	/**
	 * update
	 */
	private function update(){
		$update = $this->dbh->prepare(self::_UPDATE_);
		return $update->execute(array(
				$this->event['titre'],
				$this->event['description'],
				$this->event['dateEvent'],
				$this->event['heureDebut'],
				$this->event['heureFin'],
				$this->event['userId'],
				$this->event['emails'],
				$this->event['id']
			   ));
	}
	
	/**
	 * findByDate
	 */
	public function findByDate($date){
		$theEvents = array();
		
		$events = $this->dbh->prepare(self::_FINDBYDATE_);
		$events->execute(array($date));
		while($event = $events->fetch(PDO::FETCH_ASSOC))
			$theEvents[] = $this->loadEvent($event);
		
		if(count($theEvents > 0))
			return $theEvents;
		return false;
	}

	/**
	 * findById
	 */
	public function findById($eventId){
		$event = $this->dbh->prepare(self::_FINDBYID_);
		$event->execute(array($eventId));
		if($theEvent = $event->fetch(PDO::FETCH_ASSOC))
			return $this->loadEvent($theEvent);
		return false;
	}
	
	/**
	 * save
	 */
	public function save(){
		if($this->id == self::_NEW_)
			return $this->insert();
		else
			return $this->update();
	}
	
	/**
	 * add
	 */
	public function add($params = array()){
		foreach($params as $param => $value)
			$this->__set($param, $value);
		
		// add to the database
	}

	/**
	 * delete
	 */
	public function delete(){
		
		if($this->id != self::_NEW_){
			$stmt = $this->dbh->prepare(self::_DELETE_);
			return $stmt->execute(array($this->id));
		}
		else
			throw new exception('Cannot delete an unloaded event');
		return false;	
	}

}

/** TEST *
$table = <<< END
CREATE TABLE events(
	"id"		INTEGER		PRIMARY KEY	AUTOINCREMENT,
	"titre"		varchar(50)	NOT NULL,
	"description"	text,
	"dateEvent"	char(10)	NOT NULL,
	"heureDebut"	char(5)		NOT NULL,
	"heureFin"	char(5)		NOT NULL,
	"userId"	INTEGER		NOT NULL,
	"emails"	text
);
END;

$dbPath = 'bdtest.sq3';
$dbh = new PDO('sqlite:'.$dbPath);
$dbh->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_WARNING);

$params = array(
'titre'=>'Événement test update',
'description'=>'toujours un test d\'update',
'dateEvent'=>'01-03-2006',
'heureDebut'=>'10:30',
'heureFin'=>'11:30',
'userId'=>1,
'emails'=>''
);

$usager = new event($dbh);
//$usager->add($params);
//print_r($usager);
$allThoseEvents = $usager->findByDate('01-03-2006');
var_dump($allThoseEvents);

//var_dump($usager->save());
echo '<br />';

$sth = $dbh->prepare('SELECT * FROM events');
$sth->execute();
$result = $sth->fetchAll(PDO::FETCH_BOTH);
print_r($result);*/

?>